/* init.h */

extern void initusefile(),initlog(),oldlog();
extern Boolean useKanji[MAXTRANSLATIONSALLOWED];
extern void initstuffs(int *,char **);

